Backbone Networks
==================

This module provides backbone network utilities for feature extraction and input precomputation.

.. currentmodule:: torch_concepts.data.backbone

Summary
-------

**Backbone Functions**

.. autosummary::
   :toctree: generated
   :nosignatures:

   compute_backbone_embs
   get_backbone_embs


Function Documentation
----------------------

.. autofunction:: compute_backbone_embs

.. autofunction:: get_backbone_embs
